clear all
set mem 100m
set more off
capture log close

log using $SL_log/chiefs_analysis_census63.log, replace

/*--------------------------
1. Preparing Census 63 Data
---------------------------*/

use $SL_data/63census_chiefdoms.dta

rename chief_1963 chiefcode

*Splitting two chiefdoms that were split post 1963 according to surface area:
expand 2 if inlist(chiefcode,2481,1181,3115), gen(new)
replace chiefcode = 2408 if chiefcode==2481 & new ==1
replace chiefcode = 2409 if chiefcode==2481 & new ==0
replace chiefcode = 1106 if chiefcode==1181 & new ==1
replace chiefcode = 1107 if chiefcode==1181 & new ==0
replace chiefcode = 3411 if chiefcode==3115 & new ==0

rename new split
replace split = 1 if inlist(chiefcode,2408,2409,1106,1107,3115,3411)==1

foreach var of varlist ?age* t_* ?lit* ?labor*{
  replace `var' = `var'*.53466302 if chiefcode==1106
  replace `var' = `var'*.46533698 if chiefcode==1107
  replace `var' = `var'*.37203309 if chiefcode==2408
  replace `var' = `var'*.62796691 if chiefcode==2409
  replace `var' = `var'*.5345296 if chiefcode==3115
  replace `var' = `var'*.4654704 if chiefcode==3411
}

*Making Variables
foreach k in t m f{
rename `k'age_all `k'ageall_doc
}

gen tage_10p =0
foreach var of varlist tage??_?? tage??p{
  replace tage_10p = tage_10p + `var'
}

gen tlabor_pct_all = tlaborall/tage_10p

foreach k in t m f{
gen `k'age45p = `k'age45_49 + `k'age50_54 + `k'age55_59 + `k'age60_64 + `k'age65p
gen `k'labor45p = `k'labor45_54 + `k'labor55p
gen `k'age35_44 = `k'age35_39 + `k'age40_44
gen `k'age45_54 = `k'age45_49 + `k'age50_54
gen `k'age55p = `k'age55_59 + `k'age60_64 + `k'age65p
gen `k'litall = `k'lit10_14  + `k'lit15_19 + `k'lit20_24 + `k'lit25_29 + `k'lit30_34 + `k'lit35_39 + `k'lit40_44 + `k'lit45p 

gen `k'age20_29 = `k'age20_24 + `k'age25_29 
gen `k'lit20_29 = `k'lit20_24 + `k'lit25_29  
gen `k'labor20_29 = `k'labor20_24 + `k'labor25_29 
}

foreach age in all 10_14 15_19 20_24 25_29 30_34 35_39 40_44 45p{
  foreach k in t m f{
  gen `k'lit_pct_`age' = `k'lit`age'/`k'age`age'
}
}

/*Keeping Just Literacy*/
keep chiefcode tlit_pct*

/*Dropping Duplicated Chiefdom, Town Chiefdoms, and Western Area*/
drop if chiefcode>4000 | chiefcode==3291
duplicates drop

reshape long  tlit_pct_, i(chiefcode) j(age) string
rename tlit_pct lit

gen from = 1963 - real(substr(age,1,2))
gen to = 1963 - real(substr(age,4,2))
tostring from to, replace

gen birth = to + "_" + from
drop if birth == "._."
replace birth = "1914" if birth=="._1918"

keep chiefcode lit birth
sort chiefcode birth

tempfile lit63
save `lit63'

/*-------------------------------------
2. 2004 Census Data
-------------------------------------*/

clear
set mem 5000m
use $SL_data/census_2004_roster.dta

rename chiefdom chiefcode
*rename p11birth chiefcode
rename p5age age
gen lit = (p21liter==1)

keep chiefcode age lit

gen bdate = 2004-age

gen str birth = ""

*note stata needs version < 11 for in range to be not inclusive.
replace birth = "1954_1958" if inrange(bdate,1953,1959)
replace birth = "1959_1963" if inrange(bdate,1958,1964)
replace birth = "1964_1968" if inrange(bdate,1963,1969)
replace birth = "1969_1973" if inrange(bdate,1968,1974)
replace birth = "1974_1978" if inrange(bdate,1973,1979)
replace birth = "1979_1983" if inrange(bdate,1980,1984)

drop bdate age
collapse  (mean) lit, by(chiefcode birth)

tempfile lit04
save `lit04'

/*---------
3. Bringing Everything Together
------------*/

append using `lit63'

sort chiefcode birth
merge m:1 chiefcode using $SL_data/chiefs_survey_clean_out.dta

drop if _m!=3

keep chiefcode birth lit n_chiefs amalgamation district *fam_num*

qui  tab district, gen(dist)

tempfile lit
save `lit'

/*------------
4. Regressions and Output
-------------*/
  
statsby _b _se  r = e(r2) n = e(N), by(birth) saving($SL_out/chiefs_time_redu.dta, replace) noisily : reg lit fam_num_ln n_chiefs amalgamation dist1 dist2 dist3 dist4 dist5 dist6 dist7 dist8 dist9 dist10 dist11

foreach reg in redu{
  
  use $SL_out/chiefs_time_`reg'.dta, clear

  rename _b_fam_num_ln b_`reg'
  rename _se_fam_num_ln se_`reg'
  gen ci_l_`reg' = b_`reg' - 1.96*se_`reg'
  gen ci_u_`reg' = b_`reg' + 1.96*se_`reg'
  rename _eq2_r r2_redu
  rename _eq2_n N_redu
  keep birth *`reg' r2 N

}

/*Printing Graph*/
gen byear = real(substr(birth,1,4))
replace byear = 1914 if byear==1918
replace byear = byear + 2.5

drop birth
rename byear birth

graph twoway (connected b_redu birth, msize(small) mstyle(circle) ) (connected ci_l_redu birth,   msize(small) mstyle(circle) lpattern(dot)) (connected ci_u_redu birth,   msize(small) mstyle(circle) lpattern(dot)), legend(off)  ytitle(Coefficient of log(number of families) ) xtitle(Mean cohort birth year) scheme(sj)

graph save $SL_graph/chiefs_time, replace

/*Printing Table 7*/
drop ci*
order birth b_redu se_redu r2_redu 
tab birth
des
  
xpose, clear
outsheet using $SL_out/chiefs_table_7.csv, comma replace
